@@ -12,16 +12,16 @@ def main():
             headings.UnusedFiles,
             headings.PreventInlineStyles,
             headings.OneLoadBlock,
-            headings.AllTagsUsed,
             headings.EnsureAllIDsAreUnique,
             headings.BlockOrdering,
             headings.BlocksSpacing,
             headings.PreventTwoPaneOverwite,
             headings.CheckFilenames,
-            headings.EnforceBlockTitle,
-            headings.FindHardcodedStrings,
-            headings.EnforceSingleQuotesInBlocks,
-            headings.TabsOverSpaces,
+            # headings.AllTagsUsed,
+            # headings.EnforceBlockTitle,
+            # headings.FindHardcodedStrings,
+            # headings.EnforceSingleQuotesInBlocks,
+            # headings.TabsOverSpaces,
         ]
     ).output()
 
